(function($){
	'use strict';
	
	
	/**
	* set cookie
	* @param {Object} self - 'this' object
	* @param {string} name 
	* @param {string} value 
	*/
	var set_cookie = function(self, name, value){					
	
		var c_value = escape(value)
			,exdate = new Date();
		
		if(self.options.expiration == -1){
			document.cookie = name + '=' + c_value + ';path=/;';
		}
		else{
			var expiration = parseInt(self.options.expiration, 10);	
			exdate.setDate(exdate.getDate() + expiration); 
			document.cookie = name + '=' + c_value + ';path=/; expires=' + exdate.toUTCString();
		}		
	};
	
	/**
	* get cookie
	* @param {Object} self - 'this' object
	* @param {string} c_name - cookie name 
	* @return {string} - cookie value
	*/
	var get_cookie = function(self, c_name){
	
		var i, x, y, ARRcookies;
		ARRcookies = document.cookie.split(';');
		
		for (i=0; i<ARRcookies.length; i++){

			x = ARRcookies[i].substr(0,ARRcookies[i].indexOf('='));
			y = ARRcookies[i].substr(ARRcookies[i].indexOf('=')+1);
			x = x.replace(/^\s+|\s+$/g,'');

			if (x == c_name){
				return unescape(y);
			}

		}
		
		return '';
	};
	
	/**
	* set cookies list
	* @param {Object} self - 'this' object
	* @param {Object} properties 
	*/
	var set_cookies = function(self, properties){
	
		self.set_cookie('fs', properties.font_size); 
		self.set_cookie('ta', properties.text_align);
		self.set_cookie('fw', properties.font_weight);		
		self.set_cookie('ff', properties.font_family); 
		self.set_cookie('co', properties.color); 
		
	};
	
	/**
	* clear cookies
	* @param {Object} self - 'this' object
	*/
	var clear = function(self){
		set_cookie(self, 'fs', ''); 
		set_cookie(self, 'ta', '');
		set_cookie(self, 'fw', '');		
		set_cookie(self, 'ff', ''); 
		set_cookie(self, 'co', ''); 
	};
	
	/**
	* get cookies object
	* @param {Object} self - 'this' object
	* @param {Object} properties
	* @return {Object}
	*/
	var get_cookies = function(self, properties){
		
		return { 
			font_size: get_cookie(self, 'fs').toString()
			,text_align: get_cookie(self, 'ta').toString()
			,font_weight: get_cookie(self, 'fw').toString()
			,font_family: get_cookie(self, 'ff').toString()
			,color: get_cookie(self, 'co').toString()
		}; 
	};
	
	/**
	* init
	* @constructor 
	* @param {Object} options
	*/
	var init = function(options){
	
		var self = {
	
			options: options
		};
		
		return jQuery.extend(this, self); 	
	};

	//api ---------------------------------	
	
	/**
	* set cookie
	* @param {string} name 
	* @param {string} value 
	*/
	init.prototype.set_cookie = function(name, value){						
		set_cookie(this, name, value);	
	};
	
	/**
	* get cookie
	* @param {string} c_name - cookie name 
	* @return {string} - cookie value
	*/
	init.prototype.get_cookie = function(c_name){	
		return get_cookie(this, c_name);
	};
	
	/**
	* set cookies list
	* @param {Object} properties 
	*/
	init.prototype.set_cookies = function(properties){	
		set_cookies(this, properties);
	};
	
	/**
	* clear cookies
	*/
	init.prototype.clear = function(){
		clear(this);
	};
	
	/**
	* get cookies object
	* @param {Object} properties
	* @return {Object}
	*/
	init.prototype.get_cookies = function(properties){		
		return get_cookies(this, properties);
	};
	
	
	/** 
	* cookies
	* @constructor
	* @param {Object} options
	*/
	$.fn.zoom.cookies = function(options){
	
		var self = new init(options);		
		
		//return api object
		return self;
	};
	
})(jQuery);
