(function($){
	'use strict';	
	
	/**
	* callback
	* @param {Object} self - 'this' object
	* @param {string} type
	* @param {string} data
	*/
	var callback = function(self, type, data){
	
		//save cookies
		if(self.options.cookies){
			self.cookies.set_cookies(self.properties);
		}
		
		if($.isFunction(self.options.callback)){
			self.options.callback(type, data);
		}
	};
	
	/**
	* reset
	* @param {Object} self - 'this' object
	*/
	var reset = function(self){	
		
		self.properties = $.extend({}, self.deafult_properties);		
		self.cookies.clear();
		self.content.restore(self.properties);
		self.panel.restore(self.properties);
	};
	
	/**
	* start action like zoom, font change, color change, etc.
	* @param {Object} self - 'this' object
	* @param {string} event_type - event type
	* @param {string} value
	*/
	var perform_event = function(self, event_type, value){
		
		switch(event_type){
			case 'zoom-in':{			 
				self.properties.font_size++;
				self.properties.line_height = self.properties.font_size + self.options.line_height_step;
				
				//update css
				self.content.path.css('font-size', self.properties.font_size + 'px');
				self.content.path.css('line-height', self.properties.line_height + 'px');
				
				callback(self, 'font-size', self.properties.font_size);
				break;
			}
			case 'zoom-out':{
				self.properties.font_size--;
				self.properties.line_height = self.properties.font_size + self.options.line_height_step;
				
				//update css
				self.content.path.css('font-size', self.properties.font_size + 'px');
				self.content.path.css('line-height', self.properties.line_height + 'px');
				
				callback(self, 'font-size', self.properties.font_size);
				break;
			}
			case 'font':{					
				self.properties.font_family = value;
				self.content.path.css('font-family', self.properties.font_family);
				callback(self, 'font-family', self.properties.font_family);
				break;
			}
			case 'left':{
				self.properties.text_align = 'left';
				self.content.path.css('text-align', self.properties.text_align);
				callback(self, 'text-align', self.properties.text_align);
				break;
			}
			case 'center':{
				self.properties.text_align = 'center';
				self.content.path.css('text-align', self.properties.text_align);
				callback(self, 'text-align', self.properties.text_align);
				break;
			}
			case 'right':{
				self.properties.text_align = 'right';
				self.content.path.css('text-align', self.properties.text_align);
				callback(self, 'text-align', self.properties.text_align);
				break;
			}
			case 'color':{
				self.properties.color = value;
				self.content.path.css('color', self.properties.color);
				callback(self, 'color', self.properties.color);
				break;
			}
			case 'bold':{
				if(self.properties.font_weight == 'bold'){
					self.properties.font_weight = 'normal';
				}
				else{
					self.properties.font_weight = 'bold';
				}
				self.content.path.css('font-weight', self.properties.font_weight);
				callback(self, 'font-weight', self.properties.font_weight);
				break;
			}
			case 'reset':{
				reset(self);
				callback(self, 'reset', '');
				break;
			}
		}
	};
	
	/**
	* restore data from cookies
	* @param {Object} self - 'this' object
	*/
	var	restore_data_from_cookies = function(self){
	
		var cookies_properties = self.cookies.get_cookies();
		
		//update properties object ---------------------------------
		
		//font-size
		if($['isNumeric'](cookies_properties.font_size)){
			self.properties.font_size = cookies_properties.font_size;
		}
		
		//line-height
		self.properties.line_height = eval(self.properties.font_size) + self.options.line_height_step;
		
		//text-align
		if(cookies_properties.text_align == 'left' ||
		   cookies_properties.text_align == 'center' || 
		   cookies_properties.text_align == 'right'){
				self.properties.text_align = cookies_properties.text_align;
		   }
		   
		//font-weight
		if(cookies_properties.font_weight != ''){
			self.properties.font_weight = cookies_properties.font_weight;
		}
		
		//font-family
		if(cookies_properties.font_family != ''){
			self.properties.font_family = cookies_properties.font_family;
		}
		
		//color
		if(cookies_properties.color != ''){
			self.properties.color = cookies_properties.color;
		}
	};
	
	/**
	* init properties
	* @param {Object} self - 'this' object
	*/
	var init_properties = function(self){
		
		//get default properties
		self.deafult_properties = self.content.get_default_prop();
		
		//get properties
		self.properties = self.content.get_default_prop();
		
		//restore data from cookies
		if(self.options.cookies){		
			restore_data_from_cookies(self);	
		}
		
		self.content.restore(self.properties);
		self.panel.restore(self.properties);
	};
	
	/** 
	* index
	* @constructor 
	* @param {Object} options
	* @param {jQueryObject} box
	*/
	var init = function(options, box){
		
		var self = {
	
			//properties
			options: options
			,box: box
			
			//classes
			,cookies: null			
			,panel: null
			,content: null
			,deafult_properties: null
			,properties: null
		};
	
		//create cookies instance
		self.cookies = new $.fn.zoom.cookies(self.options);
		
		//create panel instance
		self.panel = new $.fn.zoom.panel(self.options, self.box, function(event_type, value){
			perform_event(self, event_type, value);
		});
		
		//create content instance
		self.content = new $.fn.zoom.content(self.options, self.options.path, self.panel);
		
		//init properties
		init_properties(self);
	};
			
	/** 
	* index
	* @constructor 
	* @param {Object} options
	* @param {jQueryObject} box
	*/
	$.fn.zoom.index = function(options, box){
		
		var self;
		
		//constructor
		self = new init(options, box);
		
		//return api object
		return self;
	};
	
})(jQuery);
