(function($){
	'use strict';	
	
	/**
	* color onclick
	* @param {Object} self - 'this' object
	*/
	var init_color_item_click = function(self){	
		self.buttons.colors_list.find('li').each(function(){
		
			var data_color = $(this).attr('data-color');
			
			//init background color
			$(this).css('background-color', data_color);
			
			//init click event
			$(this).click(function(){
							
				//update preview color
				if(self.buttons.color_preview.length > 0){
					self.buttons.color_preview.css('background-color', data_color);
				}
				
				//callback
				self.callback('color', data_color);
			});
		});
	};	
	
	/**
	* init events
	* @param {Object} self - 'this' object
	*/
	var init_events = function(self){
	
		//font-size buttons click-------------------------------------------------------------------
		//zoom in click
		if(self.buttons.zoom_in.length > 0){
			self.buttons.zoom_in.click(function(){				
				self.callback('zoom-in', '');
			});
		}
		
		//zoom out click
		if(self.buttons.zoom_out.length > 0){
			self.buttons.zoom_out.click(function(){
				self.callback('zoom-out', '');
			});
		}
		
		//font-family ---------------------------------------------------------------------
		//font type change
		if(self.buttons.font.length > 0){
			self.buttons.font.change(function(){
				var selected = $(this).find('option:selected').val();
				self.callback('font', selected);
				self.buttons.font.val(selected);
			});
		}
		
		//text-align ----------------------------------------------------------------------
		//left click
		if(self.buttons.left.length > 0){
			self.buttons.left.click(function(){
				self.callback('left', '');
			});
		}
		
		//center click
		if(self.buttons.center.length > 0){
			self.buttons.center.click(function(){
				self.callback('center', '');	
			});
		}
		
		//right click
		if(self.buttons.right.length > 0){
			self.buttons.right.click(function(){			
				self.callback('right', '');	
			});
		}
		
		//color ------------------------------------------------------------------------		
		//color click
		if(self.buttons.color_box.length > 0){
			self.buttons.color_box.click(function(e){
			
				var colors_list = $(this).find('.zoom-colors-list');
				e.stopPropagation();
				
				if(colors_list.is(':visible')){
					colors_list.hide(0);
				}
				else{
					colors_list.show(0);
				}
			});
			
			$(document).click(function(){
				self.buttons.colors_list.hide(0);
			});
			
			//color item click
			init_color_item_click(self);
		}
		
		//font-weight ------------------------------------------------------------------
		//bold click
		if(self.buttons.bold.length > 0){
			self.buttons.bold.click(function(){			
				self.callback('bold', '');	
			});
		}
		
		//reset ------------------------------------------------------------------
		//reset button click
		if(self.buttons.reset.length > 0){
			self.buttons.reset.click(function(){
				self.callback('reset', '');	
			});
		}
	};
	
	/**
	* init html
	* @param {Object} self - 'this' object
	*/
	var init_html = function(self){
	
		var html = '<ul class="zoom-list">';
		
			//font-size buttons visibility
			if(self.options.show_zoom){
				html += '<li class="zoom-in"></li>';
				html += '<li class="zoom-out"></li>';
			}
			
			//font-family drop down visibility
			if(self.options.show_font_family){
				html += '<li class="zoom-font-family">';
					html += '<select>'
					for(var i=0; i<self.options.fonts.length; i++){
						html += '<option>' + self.options.fonts[i] + '</option>';
					}
					html += '</select>'
				html += '</li>';
			}
			
			//text-align buttons visibility
			if(self.options.show_alignment){
				html += '<li class="zoom-left"></li>';
				html += '<li class="zoom-center"></li>';
				html += '<li class="zoom-right"></li>';
			}
			
			//colors box visibility
			if(self.options.show_colors){
				html += '<li class="zoom-color">';	
					html += '<div class="color-preview"></div>';
					html += '<ul class="zoom-colors-list">';
						for(var i=0; i<self.options.colors.length; i++){
							html += '<li data-color="' + self.options.colors[i] + '"></li>';
						}
					html += '</ul>';
				html += '</li>';
			}
			
			//font-weight button visibility
			if(self.options.show_bold){
				html += '<li class="zoom-bold"</li>';
			}
			
			//reset button visibility
			if(self.options.show_reset){
				html += '<li class="zoom-reset"></li>';
			}	
		
		html += '</ul>';
		
		self.box.html(html);
	};
	
	/**
	* restore
	* @param {Object} self - 'this' object
	* @param {Object} cookies_properties
	*/
	var restore = function(self, cookies_properties){
	
		//restore color
		if(self.buttons.color_preview.length > 0){
			self.buttons.color_preview.css('background-color', cookies_properties.color);
		}
		
		//restore font-family
		self.buttons.font.val(cookies_properties.font_family);
	};
		
	/**
	* init
	* @constructor 
	* @param {Object} options
	* @param {jQueryObject} box
	* @param {Function} callback
	*/
	var init = function(options, box, callback){
		
		var self = {
		
			//properties
			options: options
			,box: box
			,buttons: null
			
			//methods
			,callback: callback
		};
			
		//class
		self.box.addClass('zoom');		
		
		//create html
		init_html(self);
		
		//init buttons object
		self.buttons = {
		
			//zoom
			zoom_in: self.box.find('.zoom-in')		
			,zoom_out: self.box.find('.zoom-out')
			
			//font family
			,font: self.box.find('.zoom-font-family select')
			
			//text align
			,left: self.box.find('.zoom-left')
			,center: self.box.find('.zoom-center')
			,right: self.box.find('.zoom-right')
			
			//font weight
			,bold: self.box.find('.zoom-bold')
			
			//color
			,color_box: self.box.find('.zoom-color')
			,color_preview: self.box.find('.color-preview')
			,colors_list: self.box.find('.zoom-colors-list')
			
			//reset
			,reset: self.box.find('.zoom-reset')
		};
		
		return jQuery.extend(this, self); 	
	};
	
	//api ----------------------------------------------------
	
	/**
	* restore
	* @param {Object} cookies_properties
	*/
	init.prototype.restore = function(cookies_properties){
		restore(this, cookies_properties);
	};
					
	/** 
	* panel
	* @constructor 
	* @param {Object} options
	* @param {jQueryObject} box
	* @param {Function} callback
	* @return {Object} panel
	*/
	$.fn.zoom.panel = function(options, box, callback){
		
		var self;
		
		//constructor
		self = new init(options, box, callback);
		
		//init events
		init_events(self);
		
		//return api object
		return self;
	};
	
})(jQuery);
